@@ -23,7 +23,7 @@
 ***********************************************************************/
 
 #define _GLPSTD_STDIO
-#include "glpenv.h"
+#include "env.h"
 #include "glpmpl.h"
 
 /**********************************************************************/
